Channel ID (@username, t.me/username, t.me/joinchat/AAAAABbbbbcccc ... or channel ID in 'TGStat')
start_date
Date mentioned from
end_date
Date mentioned to
Details
A publication is considered a mention if it contains a link to a channel like username, t.me/username, t.me/username/1234.
In case of mentioning a channel, the mention_type parameter will contain the value 'channel'. If a specific publication of the channel is mentioned, then the parameter will contain the value 'post'.